pub struct ConditionalTypeAnnotation<'gc> { /* private fields */ }Expand description
Clone-with-changes builder for super::ConditionalTypeAnnotation.
Implementations
Sourceimpl<'gc> ConditionalTypeAnnotation<'gc>
impl<'gc> ConditionalTypeAnnotation<'gc>
Sourcepub fn from_node(node: &'gc ConditionalTypeAnnotation<'gc>) -> Self
pub fn from_node(node: &'gc ConditionalTypeAnnotation<'gc>) -> Self
Start from a copy of node, with no field changed yet.
Sourcepub fn build(self, gc: &'gc GCLock<'_, '_>) -> TransformResult<&'gc Node<'gc>>
pub fn build(self, gc: &'gc GCLock<'_, '_>) -> TransformResult<&'gc Node<'gc>>
Allocate the rebuilt node if a setter ran, else
TransformResult::Unchanged.
Sourcepub fn build_forced(self, gc: &'gc GCLock<'_, '_>) -> &'gc Node<'gc>
pub fn build_forced(self, gc: &'gc GCLock<'_, '_>) -> &'gc Node<'gc>
Allocate the node unconditionally, changed or not.
Sourcepub fn check_type(&mut self, check_type: &'gc Node<'gc>)
pub fn check_type(&mut self, check_type: &'gc Node<'gc>)
Set the check_type field and mark the builder changed.
Sourcepub fn extends_type(&mut self, extends_type: &'gc Node<'gc>)
pub fn extends_type(&mut self, extends_type: &'gc Node<'gc>)
Set the extends_type field and mark the builder changed.
Sourcepub fn true_type(&mut self, true_type: &'gc Node<'gc>)
pub fn true_type(&mut self, true_type: &'gc Node<'gc>)
Set the true_type field and mark the builder changed.
Sourcepub fn false_type(&mut self, false_type: &'gc Node<'gc>)
pub fn false_type(&mut self, false_type: &'gc Node<'gc>)
Set the false_type field and mark the builder changed.