pub struct ImportDeclaration<'gc> { /* private fields */ }Expand description
Clone-with-changes builder for super::ImportDeclaration.
Implementations
Sourceimpl<'gc> ImportDeclaration<'gc>
impl<'gc> ImportDeclaration<'gc>
Sourcepub fn from_node(node: &'gc ImportDeclaration<'gc>) -> Self
pub fn from_node(node: &'gc ImportDeclaration<'gc>) -> Self
Start from a copy of node, with no field changed yet.
Sourcepub fn build(self, gc: &'gc GCLock<'_, '_>) -> TransformResult<&'gc Node<'gc>>
pub fn build(self, gc: &'gc GCLock<'_, '_>) -> TransformResult<&'gc Node<'gc>>
Allocate the rebuilt node if a setter ran, else
TransformResult::Unchanged.
Sourcepub fn build_forced(self, gc: &'gc GCLock<'_, '_>) -> &'gc Node<'gc>
pub fn build_forced(self, gc: &'gc GCLock<'_, '_>) -> &'gc Node<'gc>
Allocate the node unconditionally, changed or not.
Sourcepub fn specifiers(&mut self, specifiers: NodeList<'gc>)
pub fn specifiers(&mut self, specifiers: NodeList<'gc>)
Set the specifiers field and mark the builder changed.
Sourcepub fn source(&mut self, source: &'gc Node<'gc>)
pub fn source(&mut self, source: &'gc Node<'gc>)
Set the source field and mark the builder changed.
Sourcepub fn attributes(&mut self, attributes: NodeList<'gc>)
pub fn attributes(&mut self, attributes: NodeList<'gc>)
Set the attributes field and mark the builder changed.