pub struct InferTypeAnnotation<'gc> { /* private fields */ }Expand description
Clone-with-changes builder for super::InferTypeAnnotation.
Implementations
Sourceimpl<'gc> InferTypeAnnotation<'gc>
impl<'gc> InferTypeAnnotation<'gc>
Sourcepub fn from_node(node: &'gc InferTypeAnnotation<'gc>) -> Self
pub fn from_node(node: &'gc InferTypeAnnotation<'gc>) -> Self
Start from a copy of node, with no field changed yet.
Sourcepub fn build(self, gc: &'gc GCLock<'_, '_>) -> TransformResult<&'gc Node<'gc>>
pub fn build(self, gc: &'gc GCLock<'_, '_>) -> TransformResult<&'gc Node<'gc>>
Allocate the rebuilt node if a setter ran, else
TransformResult::Unchanged.
Sourcepub fn build_forced(self, gc: &'gc GCLock<'_, '_>) -> &'gc Node<'gc>
pub fn build_forced(self, gc: &'gc GCLock<'_, '_>) -> &'gc Node<'gc>
Allocate the node unconditionally, changed or not.
Sourcepub fn type_parameter(&mut self, type_parameter: &'gc Node<'gc>)
pub fn type_parameter(&mut self, type_parameter: &'gc Node<'gc>)
Set the type_parameter field and mark the builder changed.