pub struct JSXFragment<'gc> { /* private fields */ }Expand description
Clone-with-changes builder for super::JSXFragment.
Implementations
Sourceimpl<'gc> JSXFragment<'gc>
impl<'gc> JSXFragment<'gc>
Sourcepub fn from_node(node: &'gc JSXFragment<'gc>) -> Self
pub fn from_node(node: &'gc JSXFragment<'gc>) -> Self
Start from a copy of node, with no field changed yet.
Sourcepub fn build(self, gc: &'gc GCLock<'_, '_>) -> TransformResult<&'gc Node<'gc>>
pub fn build(self, gc: &'gc GCLock<'_, '_>) -> TransformResult<&'gc Node<'gc>>
Allocate the rebuilt node if a setter ran, else
TransformResult::Unchanged.
Sourcepub fn build_forced(self, gc: &'gc GCLock<'_, '_>) -> &'gc Node<'gc>
pub fn build_forced(self, gc: &'gc GCLock<'_, '_>) -> &'gc Node<'gc>
Allocate the node unconditionally, changed or not.
Sourcepub fn opening_fragment(&mut self, opening_fragment: &'gc Node<'gc>)
pub fn opening_fragment(&mut self, opening_fragment: &'gc Node<'gc>)
Set the opening_fragment field and mark the builder changed.
Sourcepub fn children(&mut self, children: NodeList<'gc>)
pub fn children(&mut self, children: NodeList<'gc>)
Set the children field and mark the builder changed.
Sourcepub fn closing_fragment(&mut self, closing_fragment: &'gc Node<'gc>)
pub fn closing_fragment(&mut self, closing_fragment: &'gc Node<'gc>)
Set the closing_fragment field and mark the builder changed.