pub struct ObjectTypeAnnotation<'gc> { /* private fields */ }Expand description
Clone-with-changes builder for super::ObjectTypeAnnotation.
Implementations
Sourceimpl<'gc> ObjectTypeAnnotation<'gc>
impl<'gc> ObjectTypeAnnotation<'gc>
Sourcepub fn from_node(node: &'gc ObjectTypeAnnotation<'gc>) -> Self
pub fn from_node(node: &'gc ObjectTypeAnnotation<'gc>) -> Self
Start from a copy of node, with no field changed yet.
Sourcepub fn build(self, gc: &'gc GCLock<'_, '_>) -> TransformResult<&'gc Node<'gc>>
pub fn build(self, gc: &'gc GCLock<'_, '_>) -> TransformResult<&'gc Node<'gc>>
Allocate the rebuilt node if a setter ran, else
TransformResult::Unchanged.
Sourcepub fn build_forced(self, gc: &'gc GCLock<'_, '_>) -> &'gc Node<'gc>
pub fn build_forced(self, gc: &'gc GCLock<'_, '_>) -> &'gc Node<'gc>
Allocate the node unconditionally, changed or not.
Sourcepub fn properties(&mut self, properties: NodeList<'gc>)
pub fn properties(&mut self, properties: NodeList<'gc>)
Set the properties field and mark the builder changed.
Sourcepub fn indexers(&mut self, indexers: NodeList<'gc>)
pub fn indexers(&mut self, indexers: NodeList<'gc>)
Set the indexers field and mark the builder changed.
Sourcepub fn call_properties(&mut self, call_properties: NodeList<'gc>)
pub fn call_properties(&mut self, call_properties: NodeList<'gc>)
Set the call_properties field and mark the builder changed.
Sourcepub fn internal_slots(&mut self, internal_slots: NodeList<'gc>)
pub fn internal_slots(&mut self, internal_slots: NodeList<'gc>)
Set the internal_slots field and mark the builder changed.