pub struct RecordDeclaration<'gc> { /* private fields */ }Expand description
Clone-with-changes builder for super::RecordDeclaration.
Implementations
Sourceimpl<'gc> RecordDeclaration<'gc>
impl<'gc> RecordDeclaration<'gc>
Sourcepub fn from_node(node: &'gc RecordDeclaration<'gc>) -> Self
pub fn from_node(node: &'gc RecordDeclaration<'gc>) -> Self
Start from a copy of node, with no field changed yet.
Sourcepub fn build(self, gc: &'gc GCLock<'_, '_>) -> TransformResult<&'gc Node<'gc>>
pub fn build(self, gc: &'gc GCLock<'_, '_>) -> TransformResult<&'gc Node<'gc>>
Allocate the rebuilt node if a setter ran, else
TransformResult::Unchanged.
Sourcepub fn build_forced(self, gc: &'gc GCLock<'_, '_>) -> &'gc Node<'gc>
pub fn build_forced(self, gc: &'gc GCLock<'_, '_>) -> &'gc Node<'gc>
Allocate the node unconditionally, changed or not.
Sourcepub fn type_parameters(&mut self, type_parameters: Option<&'gc Node<'gc>>)
pub fn type_parameters(&mut self, type_parameters: Option<&'gc Node<'gc>>)
Set the type_parameters field and mark the builder changed.
Sourcepub fn implements(&mut self, implements: NodeList<'gc>)
pub fn implements(&mut self, implements: NodeList<'gc>)
Set the implements field and mark the builder changed.