pub struct TSTypeReference<'gc> { /* private fields */ }Expand description
Clone-with-changes builder for super::TSTypeReference.
Implementations
Sourceimpl<'gc> TSTypeReference<'gc>
impl<'gc> TSTypeReference<'gc>
Sourcepub fn from_node(node: &'gc TSTypeReference<'gc>) -> Self
pub fn from_node(node: &'gc TSTypeReference<'gc>) -> Self
Start from a copy of node, with no field changed yet.
Sourcepub fn build(self, gc: &'gc GCLock<'_, '_>) -> TransformResult<&'gc Node<'gc>>
pub fn build(self, gc: &'gc GCLock<'_, '_>) -> TransformResult<&'gc Node<'gc>>
Allocate the rebuilt node if a setter ran, else
TransformResult::Unchanged.
Sourcepub fn build_forced(self, gc: &'gc GCLock<'_, '_>) -> &'gc Node<'gc>
pub fn build_forced(self, gc: &'gc GCLock<'_, '_>) -> &'gc Node<'gc>
Allocate the node unconditionally, changed or not.
Sourcepub fn type_name(&mut self, type_name: &'gc Node<'gc>)
pub fn type_name(&mut self, type_name: &'gc Node<'gc>)
Set the type_name field and mark the builder changed.
Sourcepub fn type_parameters(&mut self, type_parameters: Option<&'gc Node<'gc>>)
pub fn type_parameters(&mut self, type_parameters: Option<&'gc Node<'gc>>)
Set the type_parameters field and mark the builder changed.