pub struct TSVoidKeyword<'gc> { /* private fields */ }Expand description
Clone-with-changes builder for super::TSVoidKeyword.
Implementations
Sourceimpl<'gc> TSVoidKeyword<'gc>
impl<'gc> TSVoidKeyword<'gc>
Sourcepub fn from_node(node: &'gc TSVoidKeyword<'gc>) -> Self
pub fn from_node(node: &'gc TSVoidKeyword<'gc>) -> Self
Start from a copy of node, with no field changed yet.
Sourcepub fn build(self, gc: &'gc GCLock<'_, '_>) -> TransformResult<&'gc Node<'gc>>
pub fn build(self, gc: &'gc GCLock<'_, '_>) -> TransformResult<&'gc Node<'gc>>
Allocate the rebuilt node if a setter ran, else
TransformResult::Unchanged.
Sourcepub fn build_forced(self, gc: &'gc GCLock<'_, '_>) -> &'gc Node<'gc>
pub fn build_forced(self, gc: &'gc GCLock<'_, '_>) -> &'gc Node<'gc>
Allocate the node unconditionally, changed or not.