pub struct TupleTypeLabeledElement<'gc> { /* private fields */ }Expand description
Clone-with-changes builder for super::TupleTypeLabeledElement.
Implementations
Sourceimpl<'gc> TupleTypeLabeledElement<'gc>
impl<'gc> TupleTypeLabeledElement<'gc>
Sourcepub fn from_node(node: &'gc TupleTypeLabeledElement<'gc>) -> Self
pub fn from_node(node: &'gc TupleTypeLabeledElement<'gc>) -> Self
Start from a copy of node, with no field changed yet.
Sourcepub fn build(self, gc: &'gc GCLock<'_, '_>) -> TransformResult<&'gc Node<'gc>>
pub fn build(self, gc: &'gc GCLock<'_, '_>) -> TransformResult<&'gc Node<'gc>>
Allocate the rebuilt node if a setter ran, else
TransformResult::Unchanged.
Sourcepub fn build_forced(self, gc: &'gc GCLock<'_, '_>) -> &'gc Node<'gc>
pub fn build_forced(self, gc: &'gc GCLock<'_, '_>) -> &'gc Node<'gc>
Allocate the node unconditionally, changed or not.
Sourcepub fn label(&mut self, label: &'gc Node<'gc>)
pub fn label(&mut self, label: &'gc Node<'gc>)
Set the label field and mark the builder changed.
Sourcepub fn element_type(&mut self, element_type: &'gc Node<'gc>)
pub fn element_type(&mut self, element_type: &'gc Node<'gc>)
Set the element_type field and mark the builder changed.