pub struct TypeofTypeAnnotation<'gc> { /* private fields */ }Expand description
Clone-with-changes builder for super::TypeofTypeAnnotation.
Implementations
Sourceimpl<'gc> TypeofTypeAnnotation<'gc>
impl<'gc> TypeofTypeAnnotation<'gc>
Sourcepub fn from_node(node: &'gc TypeofTypeAnnotation<'gc>) -> Self
pub fn from_node(node: &'gc TypeofTypeAnnotation<'gc>) -> Self
Start from a copy of node, with no field changed yet.
Sourcepub fn build(self, gc: &'gc GCLock<'_, '_>) -> TransformResult<&'gc Node<'gc>>
pub fn build(self, gc: &'gc GCLock<'_, '_>) -> TransformResult<&'gc Node<'gc>>
Allocate the rebuilt node if a setter ran, else
TransformResult::Unchanged.
Sourcepub fn build_forced(self, gc: &'gc GCLock<'_, '_>) -> &'gc Node<'gc>
pub fn build_forced(self, gc: &'gc GCLock<'_, '_>) -> &'gc Node<'gc>
Allocate the node unconditionally, changed or not.
Sourcepub fn argument(&mut self, argument: &'gc Node<'gc>)
pub fn argument(&mut self, argument: &'gc Node<'gc>)
Set the argument field and mark the builder changed.
Sourcepub fn type_arguments(&mut self, type_arguments: Option<&'gc Node<'gc>>)
pub fn type_arguments(&mut self, type_arguments: Option<&'gc Node<'gc>>)
Set the type_arguments field and mark the builder changed.