NodeField

Enum NodeField 

pub enum NodeField {
Show 104 variants alternate, argument, arguments, attributes, base, block, body, bound, call_properties, callee, cases, check_type, children, closing_element, closing_fragment, consequent, constraint, declaration, declarations, decorators, default, default_value, discriminant, element_type, element_types, elements, exported, expr_name, expression, expressions, extends, extends_type, false_type, finalizer, guard, handler, id, implements, impltype, imported, index_type, indexers, init, initializer, internal_slots, key, key_tparam, label, left, literal, local, lower_bound, members, meta, mixins, name, namespace, object, object_type, opening_element, opening_fragment, options, param, parameter, parameter_name, parameters, params, pattern, patterns, predicate, prop_type, properties, property, qualification, quasi, quasis, record_constructor, renders_type, rest, return_type, right, source, source_type, specifiers, super_class, super_type_arguments, supertype, tag, target, target_constructor, test, this, true_type, ts_modifiers, type_annotation, type_arguments, type_name, type_parameter, type_parameters, types, update, upper_bound, value, variance,
}
The name of a structural child field of an AST node (used in Path).

Variants



alternate

The alternate child field.



argument

The argument child field.



arguments

The arguments child field.



attributes

The attributes child field.



base

The base child field.



block

The block child field.



body

The body child field.



bound

The bound child field.



call_properties

The call_properties child field.



callee

The callee child field.



cases

The cases child field.



check_type

The check_type child field.



children

The children child field.



closing_element

The closing_element child field.



closing_fragment

The closing_fragment child field.



consequent

The consequent child field.



constraint

The constraint child field.



declaration

The declaration child field.



declarations

The declarations child field.



decorators

The decorators child field.



default

The default child field.



default_value

The default_value child field.



discriminant

The discriminant child field.



element_type

The element_type child field.



element_types

The element_types child field.



elements

The elements child field.



exported

The exported child field.



expr_name

The expr_name child field.



expression

The expression child field.



expressions

The expressions child field.



extends

The extends child field.



extends_type

The extends_type child field.



false_type

The false_type child field.



finalizer

The finalizer child field.



guard

The guard child field.



handler

The handler child field.



id

The id child field.



implements

The implements child field.



impltype

The impltype child field.



imported

The imported child field.



index_type

The index_type child field.



indexers

The indexers child field.



init

The init child field.



initializer

The initializer child field.



internal_slots

The internal_slots child field.



key

The key child field.



key_tparam

The key_tparam child field.



label

The label child field.



left

The left child field.



literal

The literal child field.



local

The local child field.



lower_bound

The lower_bound child field.



members

The members child field.



meta

The meta child field.



mixins

The mixins child field.



name

The name child field.



namespace

The namespace child field.



object

The object child field.



object_type

The object_type child field.



opening_element

The opening_element child field.



opening_fragment

The opening_fragment child field.



options

The options child field.



param

The param child field.



parameter

The parameter child field.



parameter_name

The parameter_name child field.



parameters

The parameters child field.



params

The params child field.



pattern

The pattern child field.



patterns

The patterns child field.



predicate

The predicate child field.



prop_type

The prop_type child field.



properties

The properties child field.



property

The property child field.



qualification

The qualification child field.



quasi

The quasi child field.



quasis

The quasis child field.



record_constructor

The record_constructor child field.



renders_type

The renders_type child field.



rest

The rest child field.



return_type

The return_type child field.



right

The right child field.



source

The source child field.



source_type

The source_type child field.



specifiers

The specifiers child field.



super_class

The super_class child field.



super_type_arguments

The super_type_arguments child field.



supertype

The supertype child field.



tag

The tag child field.



target

The target child field.



target_constructor

The target_constructor child field.



test

The test child field.



this

The this child field.



true_type

The true_type child field.



ts_modifiers

The ts_modifiers child field.



type_annotation

The type_annotation child field.



type_arguments

The type_arguments child field.



type_name

The type_name child field.



type_parameter

The type_parameter child field.



type_parameters

The type_parameters child field.



types

The types child field.



update

The update child field.



upper_bound

The upper_bound child field.



value

The value child field.



variance

The variance child field.