#[repr(C)]pub struct ForOfStatement<'gc> {
pub metadata: NodeMetadata<'gc>,
pub left: &'gc Node<'gc>,
pub right: &'gc Node<'gc>,
pub body: &'gc Node<'gc>,
pub await: Cell<bool>,
pub label_index: Cell<u32>,
pub scope: Cell<Option<SemaId>>,
}Expand description
The ForOfStatement AST node.
Fields
metadata: NodeMetadata<'gc>Source range, debug location, paren count, and node id.
left: &'gc Node<'gc>ESTree left property.
right: &'gc Node<'gc>ESTree right property.
body: &'gc Node<'gc>ESTree body property.
await: Cell<bool>ESTree await property.
label_index: Cell<u32>Sema: label index; INVALID_LABEL until set.
scope: Cell<Option<SemaId>>Sema: the lexical scope created by this node, if any.
Implementations
Sourceimpl<'gc> ForOfStatement<'gc>
impl<'gc> ForOfStatement<'gc>