#[repr(C)]pub struct ForStatement<'gc> {
pub metadata: NodeMetadata<'gc>,
pub init: Option<&'gc Node<'gc>>,
pub test: Option<&'gc Node<'gc>>,
pub update: Option<&'gc Node<'gc>>,
pub body: &'gc Node<'gc>,
pub label_index: Cell<u32>,
pub scope: Cell<Option<SemaId>>,
}Expand description
The ForStatement AST node.
Fields
metadata: NodeMetadata<'gc>Source range, debug location, paren count, and node id.
init: Option<&'gc Node<'gc>>ESTree init property.
test: Option<&'gc Node<'gc>>ESTree test property.
update: Option<&'gc Node<'gc>>ESTree update property.
body: &'gc Node<'gc>ESTree body property.
label_index: Cell<u32>Sema: label index; INVALID_LABEL until set.
scope: Cell<Option<SemaId>>Sema: the lexical scope created by this node, if any.
Implementations
Sourceimpl<'gc> ForStatement<'gc>
impl<'gc> ForStatement<'gc>