#[repr(C)]pub struct StaticBlock<'gc> {
pub metadata: NodeMetadata<'gc>,
pub body: NodeList<'gc>,
pub scope: Cell<Option<SemaId>>,
pub function_info: Cell<Option<SemaId>>,
}Expand description
The StaticBlock AST node.
Fields
metadata: NodeMetadata<'gc>Source range, debug location, paren count, and node id.
body: NodeList<'gc>ESTree body property.
scope: Cell<Option<SemaId>>Sema: the lexical scope created by this node, if any.
function_info: Cell<Option<SemaId>>Sema: FunctionInfo for this static block.
Implementations
Sourceimpl<'gc> StaticBlock<'gc>
impl<'gc> StaticBlock<'gc>
Sourcepub fn new(metadata: NodeMetadata<'gc>, body: NodeList<'gc>) -> Self
pub fn new(metadata: NodeMetadata<'gc>, body: NodeList<'gc>) -> Self
Build StaticBlock from its metadata and ESTree.def fields.
Decoration fields start at their defaults.